@@ -1,7 +1,7 @@
 ### SHELL> mpiexec -np 2 Rscript --vanilla [...].r
 
 ### Initial.
-library(pbdMPI, quietly = TRUE)
+suppressMessages(library(pbdMPI, quietly = TRUE))
 init()
 .comm.size <- comm.size()
 .comm.rank <- comm.rank()
@@ -31,5 +31,18 @@ comm.print(y)
 comm.cat("\n-- Print from rank 1:\n", rank.print = 1, quiet = TRUE)
 comm.print(y, rank.print = 1)
 
+comm.set.seed(1234, diff = TRUE)
+x <- as.logical(round(runif(N)))
+comm.print(x, all.rank = TRUE)
+
+y <- reduce(x, op = "land")
+comm.cat("\nReduce land:\n", quiet = TRUE)
+comm.print(y)
+
+y <- reduce(x, op = "lor")
+comm.cat("\nReduce lor:\n", quiet = TRUE)
+comm.print(y)
+
+
 ### Finish.
 finalize()
